@@ -240,7 +240,6 @@ class ThePoly(GenericGeometry):
             # 		ThePoly(diff_result_i).plot()
             # 	plt.show()
 
-
             except:
                 # # raw_poly.plot()
                 # valid_poly.plot()
@@ -895,6 +894,9 @@ class ThePoly(GenericGeometry):
         else:
             return super().__getitem__(item)
 
+    def __hash__(self):
+        return self.geometry.wkt
+
 
 class TheChunk(ThePoly):
 
