@@ -761,6 +761,9 @@ class FieldPoly(ThePoly):
         obj = {'type': 'Polygon', 'coordinates': [coords]}
         return area(obj)
 
+    def __hash__(self):
+        return self.geometry.wkt
+
 
 def get_vis_poly(polygon: FieldPoly):
     return vis.Polygon([vis.Point(*xy) for xy in polygon.xy[:-1]])
